==> qtjambi-xml-5.15.8-sources.jar: io/qt/xml/QXmlNamespaceSupport.java <==
package io.qt.xml;


/**
 * <p>Helper class for XML readers which want to include namespace support</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html">QXmlNamespaceSupport</a></p>
 */
@Deprecated
public class QXmlNamespaceSupport extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#QXmlNamespaceSupport">QXmlNamespaceSupport::QXmlNamespaceSupport()</a></p>
     */
    public QXmlNamespaceSupport(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlNamespaceSupport instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#popContext">QXmlNamespaceSupport::popContext()</a></p>
     */
    @io.qt.QtUninvokable
    public final void popContext(){
        popContext_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void popContext_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#prefix">QXmlNamespaceSupport::prefix(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String prefix(java.lang.String arg__1){
        return prefix_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String prefix_native_cref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#prefixes">QXmlNamespaceSupport::prefixes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList prefixes(){
        return prefixes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList prefixes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#prefixes-1">QXmlNamespaceSupport::prefixes(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList prefixes(java.lang.String arg__1){
        return prefixes_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList prefixes_native_cref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#processName">QXmlNamespaceSupport::processName(QString,bool,QString&amp;,QString&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QXmlNamespaceSupport.ProcessedName processName(java.lang.String arg__1, boolean arg__2){
        return processName_native_cref_QString_bool_ref_QString_ref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1, arg__2);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlNamespaceSupport.ProcessedName processName_native_cref_QString_bool_ref_QString_ref_QString_constfct(long __this__nativeId, java.lang.String arg__1, boolean arg__2);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#pushContext">QXmlNamespaceSupport::pushContext()</a></p>
     */
    @io.qt.QtUninvokable
    public final void pushContext(){
        pushContext_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void pushContext_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#reset">QXmlNamespaceSupport::reset()</a></p>
     */
    @io.qt.QtUninvokable
    public final void reset(){
        reset_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void reset_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#setPrefix">QXmlNamespaceSupport::setPrefix(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPrefix(java.lang.String arg__1, java.lang.String arg__2){
        setPrefix_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1, arg__2);
    }
    
    @io.qt.QtUninvokable
    private native void setPrefix_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String arg__1, java.lang.String arg__2);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#splitName">QXmlNamespaceSupport::splitName(QString,QString&amp;,QString&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QXmlNamespaceSupport.SplitName splitName(java.lang.String arg__1){
        return splitName_native_cref_QString_ref_QString_ref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlNamespaceSupport.SplitName splitName_native_cref_QString_ref_QString_ref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#uri">QXmlNamespaceSupport::uri(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String uri(java.lang.String arg__1){
        return uri_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String uri_native_cref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlNamespaceSupport(QPrivateConstructor p) { super(p); } 
    
    public static final class ProcessedName {
        private ProcessedName(String nsuri, String localName) {
            this.nsuri = nsuri;
            this.localName = localName;
        }
    
        public final String nsuri;
        public final String localName;
    }
    
    public static final class SplitName {
        private SplitName(String prefix, String localname) {
            this.prefix = prefix;
            this.localname = localname;
        }
    
        public final String prefix;
        public final String localname;
    }
    
    @Override
    public QXmlNamespaceSupport clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlNamespaceSupport clone_native(long __this_nativeId);
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QXmlNamespaceSupport.java <==
package io.qt.xml;


/**
 * <p>Helper class for XML readers which want to include namespace support</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html">QXmlNamespaceSupport</a></p>
 */
@Deprecated
public class QXmlNamespaceSupport extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#QXmlNamespaceSupport">QXmlNamespaceSupport::QXmlNamespaceSupport()</a></p>
     */
    public QXmlNamespaceSupport(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlNamespaceSupport instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#popContext">QXmlNamespaceSupport::popContext()</a></p>
     */
    @io.qt.QtUninvokable
    public final void popContext(){
        popContext_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void popContext_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#prefix">QXmlNamespaceSupport::prefix(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String prefix(java.lang.String arg__1){
        return prefix_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String prefix_native_cref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#prefixes">QXmlNamespaceSupport::prefixes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList prefixes(){
        return prefixes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList prefixes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#prefixes-1">QXmlNamespaceSupport::prefixes(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList prefixes(java.lang.String arg__1){
        return prefixes_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList prefixes_native_cref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#processName">QXmlNamespaceSupport::processName(QString,bool,QString&amp;,QString&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QXmlNamespaceSupport.ProcessedName processName(java.lang.String arg__1, boolean arg__2){
        return processName_native_cref_QString_bool_ref_QString_ref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1, arg__2);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlNamespaceSupport.ProcessedName processName_native_cref_QString_bool_ref_QString_ref_QString_constfct(long __this__nativeId, java.lang.String arg__1, boolean arg__2);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#pushContext">QXmlNamespaceSupport::pushContext()</a></p>
     */
    @io.qt.QtUninvokable
    public final void pushContext(){
        pushContext_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void pushContext_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#reset">QXmlNamespaceSupport::reset()</a></p>
     */
    @io.qt.QtUninvokable
    public final void reset(){
        reset_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void reset_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#setPrefix">QXmlNamespaceSupport::setPrefix(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPrefix(java.lang.String arg__1, java.lang.String arg__2){
        setPrefix_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1, arg__2);
    }
    
    @io.qt.QtUninvokable
    private native void setPrefix_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String arg__1, java.lang.String arg__2);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#splitName">QXmlNamespaceSupport::splitName(QString,QString&amp;,QString&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QXmlNamespaceSupport.SplitName splitName(java.lang.String arg__1){
        return splitName_native_cref_QString_ref_QString_ref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QXmlNamespaceSupport.SplitName splitName_native_cref_QString_ref_QString_ref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlnamespacesupport.html#uri">QXmlNamespaceSupport::uri(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String uri(java.lang.String arg__1){
        return uri_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String uri_native_cref_QString_constfct(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlNamespaceSupport(QPrivateConstructor p) { super(p); } 
    
    public static final class ProcessedName {
        private ProcessedName(String nsuri, String localName) {
            this.nsuri = nsuri;
            this.localName = localName;
        }
    
        public final String nsuri;
        public final String localName;
    }
    
    public static final class SplitName {
        private SplitName(String prefix, String localname) {
            this.prefix = prefix;
            this.localname = localname;
        }
    
        public final String prefix;
        public final String localname;
    }
    
    @Override
    public QXmlNamespaceSupport clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlNamespaceSupport clone_native(long __this_nativeId);
}
